#
# spec file for package kdnssd
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define rname kio-zeroconf
%define kf6_version 6.0.0
%define qt6_version 6.6.0

%bcond_without released
Name:           kdnssd
Version:        24.02.2
Release:        1.1.2.1
Summary:        Zeroconf Support for KIO applications
License:        GPL-2.0-or-later
URL:            https://www.kde.org
Source:         %{rname}-%{version}.tar.xz
%if %{with released}
Source1:        %{rname}-%{version}.tar.xz.sig
Source2:        applications.keyring
%endif
BuildRequires:  kf6-extra-cmake-modules >= %{kf6_version}
BuildRequires:  cmake(KF6DBusAddons) >= %{kf6_version}
BuildRequires:  cmake(KF6DNSSD) >= %{kf6_version}
BuildRequires:  cmake(KF6I18n) >= %{kf6_version}
BuildRequires:  cmake(KF6KIO) >= %{kf6_version}
BuildRequires:  cmake(Qt6Core) >= %{qt6_version}

%description
This package adds Zeroconf support to KIO, allowing the use of this protocol
in all applications that are using KIO.

%lang_package

%prep
%autosetup -p1 -n %{rname}-%{version}

%build
%ifarch ppc ppc64
export RPM_OPT_FLAGS="%{optflags} -mminimal-toc"
%endif
%cmake_kf6 -DBUILD_WITH_QT6:BOOL=TRUE

%kf6_build

%install
%kf6_install

%find_lang %{name} --all-name

%ldconfig_scriptlets

%files
%license LICENSES/*
%{_kf6_appstreamdir}/org.kde.kio_zeroconf.metainfo.xml
%{_kf6_dbusinterfacesdir}/org.kde.kdnssd.xml
%{_kf6_plugindir}/kf6/kded/dnssdwatcher.so
%{_kf6_plugindir}/kf6/kio/zeroconf.so
%dir %{_kf6_sharedir}/remoteview/
%{_kf6_sharedir}/remoteview/zeroconf.desktop

%files lang -f %{name}.lang

%changelog
* Tue Apr  9 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.02.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.02.2/
- No code change since 24.02.1
* Tue Mar 19 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.02.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.02.1/
- No code change since 24.02.0
* Fri Feb 23 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.02.0
  * New feature release
- No code change since 24.01.95
* Fri Feb  9 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.01.95
  * https://kde.org/announcements/megarelease/6/rc2/
* Tue Dec  5 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.4/
- No code change since 23.08.3
* Tue Nov  7 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.3/
- No code change since 23.08.2
* Tue Oct 10 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.2/
- No code change since 23.08.1
* Tue Sep 12 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.1/
- No code change since 23.08.0
* Sun Aug 20 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.0/
- No code change since 23.07.90
* Mon Aug 14 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.07.90
  * New feature release
- No code change since 23.07.80
* Tue Aug  1 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.07.80
  * New feature release
- No code change since 23.04.3
* Tue Jul  4 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.3/
- No code change since 23.04.2
* Tue Jun  6 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.2/
- No code change since 23.04.1
* Tue May  9 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.1/
- No code change since 23.04.0
* Sat Apr 15 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.0/
* Fri Mar 31 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.03.90
  * New feature release
* Fri Mar 17 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.03.80
  * New feature release
* Tue Feb 28 2023 Christophe Marin <christophe@krop.fr>
- Update to 22.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.3/
* Tue Jan 31 2023 Christophe Marin <christophe@krop.fr>
- Update to 22.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.2/
* Tue Jan  3 2023 Christophe Marin <christophe@krop.fr>
- Update to 22.12.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.1/
* Fri Dec  2 2022 Christophe Marin <christophe@krop.fr>
- Update to 22.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.0/
* Sat Nov 26 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.11.90
  * New feature release
* Sat Nov 12 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.11.80
  * New feature release
* Tue Nov  1 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.3/
* Tue Oct 11 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.2/
* Tue Sep  6 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.1/
* Sun Aug 14 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.0/
* Sun Jul 17 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.07.80
  * New feature release
* Tue Jul  5 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.3/
* Wed Jun  8 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.2/
* Tue May 10 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.1/
* Mon Apr 18 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.0/
* Fri Apr  8 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.03.90
  * New feature release
* Wed Mar 23 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.03.80
  * New feature release
- Changes since 21.12.3:
  * Add GitLab CI
* Tue Mar  1 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.3/
- No code change since 21.12.2
* Tue Feb  1 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.2/
- No code change since 21.12.1
* Tue Jan  4 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.1/
- No code change since 21.12.0
* Fri Dec  3 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.0/
- No code change since 21.11.90
* Sat Nov 27 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.11.90
  * New feature release
- No code change since 21.11.80
* Sat Nov 13 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.11.80
  * New feature release
- Changes since 21.08.3:
  * Bump min required KF to 5.85
* Tue Nov  2 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.08.3/
- No code change since 21.08.2
* Tue Oct  5 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.08.2/
- No code change since 21.08.1
* Wed Sep  1 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.08.1
- No code change since 21.08.0
* Fri Aug  6 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/21.08.0
- No code change since 21.07.90
* Fri Jul 30 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.07.90
  * New feature release
- No code change since 21.07.80
* Sat Jul 17 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.07.80
  * New feature release
- Changes since 21.04.3:
  * Deploy kded module with embedded JSON data
- Only install the license files once
* Wed Jul  7 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.04.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.04.3
- No code change since 21.04.2
* Tue Jun  8 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.04.2
- No code change since 21.04.1
* Wed May 12 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/21.04.1
- No code change since 21.04.0
* Fri Apr 16 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/21.04
- No code change since 21.03.90
* Fri Apr  9 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.03.90
  * New feature release
- No code change since 21.03.80
* Sun Mar 21 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.03.80
  * New feature release
- No code change since 20.12.3
* Thu Mar  4 2021 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/20.12.3
- No code change since 20.12.2
* Wed Feb  3 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2021-02-apps-update
- No code change since 20.12.1
* Tue Jan  5 2021 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.12.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2021-01-apps-update
- No code change since 20.12.0
* Sat Dec  5 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-12-apps-update
- No code change since 20.11.90
* Fri Nov 27 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.11.90
  * New feature release
- No code change since 20.11.80
* Sat Nov 14 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.11.80
  * New feature release
- No code change since 20.08.3
* Thu Nov  5 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-11-apps-update
- No code change since 20.08.2
* Fri Oct  9 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-10-apps-update
- No code change since 20.08.1
* Tue Sep  1 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-09-apps-update
- No code change since 20.08.0
* Sun Aug  9 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-08-apps-update
- No code change since 20.07.90
* Sun Aug  2 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.07.90
  * New feature release
- No code change since 20.07.80
* Sun Jul 19 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.07.80
  * New feature release
- No code change since 20.04.3
* Thu Jul  9 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.04.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-07-apps-update
- No code change since 20.04.2
* Tue Jun  9 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-06-apps-update
- No code change since 20.04.1
* Fri May 15 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-05-apps-update
- No code change since 20.04.0
* Thu Apr 23 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-04-apps-update
- No code change since 20.03.90
* Sun Apr  5 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.03.90
  * New feature release
- No code change since 20.03.80
* Sun Mar 22 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.03.80
  * New feature release
- Changes since 19.12.3:
  * It compiles fine without deprecated methods
* Thu Mar  5 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-03-apps-update
- No code change since 19.12.2
* Fri Feb  7 2020 Christophe Giboudeaux <christophe@krop.fr>
- Replace %%make_jobs with %%cmake_build.
* Wed Feb  5 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-02-apps-update
- No code change since 19.12.1
* Tue Jan  7 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 19.12.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/releases/19.12.1
- No code change since 19.12.0
* Tue Dec 10 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.12.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/releases/19.12
- No code change since 19.11.90
* Sat Nov 30 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.11.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/releases/19.12-rc
- No code change since 19.11.80
* Sun Nov 24 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.11.80
  * New feature release
- Changes since 19.08.3:
  * Use only one metainfo file
  * Rename the metainfo file
  * add screenshot
  * rename for spec compliance
  * add appstream file for use in kde.org/applications
* Thu Nov  7 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.08.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08.3.php
- No code change since 19.08.2
* Fri Oct 11 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.08.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08.2.php
- No code change since 19.08.1
* Thu Sep  5 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.08.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08.1.php
- No code change since 19.08.0
* Fri Aug  9 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 19.08.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08.0.php
- No code change since 19.07.90
* Tue Aug  6 2019 lbeltrame@kde.org
- Update to 19.07.90
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08-rc.php
- Changes since 19.07.80:
  * No code changes since 19.07.80
* Tue Jul 23 2019 lbeltrame@kde.org
- Update to 19.07.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08-beta.php
- Changes since 19.04.3:
  * No code changes since 19.04.3
* Sat Jul 13 2019 lbeltrame@kde.org
- Update to 19.04.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.04.3.php
- Changes since 19.04.2:
  * No code changes since 19.04.2
* Fri Jun  7 2019 lbeltrame@kde.org
- Update to 19.04.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.04.2.php
- Changes since 19.04.1:
  * No code changes since 19.04.1
* Fri May 10 2019 lbeltrame@kde.org
- Update to 19.04.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.04.1.php
- Changes since 19.04.0:
  * No code changes since 19.04.0
* Sat Apr 20 2019 lbeltrame@kde.org
- Update to 19.04.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.04.0.php
- Changes since 19.03.90:
  * No code changes since 19.03.90
* Tue Apr  9 2019 lbeltrame@kde.org
- Update to 19.03.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/announce-applications-19.04-rc.php
- Changes since 19.03.80:
  * No code changes since 19.03.80
* Wed Mar 27 2019 lbeltrame@kde.org
- Update to 19.03.80
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/announce-applications-19.04-beta.php
- Changes since 18.12.3:
  * No code changes since 18.12.3
* Sat Mar  9 2019 lbeltrame@kde.org
- Update to 18.12.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.3.php
- Changes since 18.12.2:
  * No code changes since 18.12.2
* Sat Feb  9 2019 lbeltrame@kde.org
- Update to 18.12.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.2.php
- Changes since 18.12.1:
  * No code changes since 18.12.1
* Fri Jan 11 2019 lbeltrame@kde.org
- Update to 18.12.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.1.php
- Changes since 18.12.0:
  * No code changes since 18.12.0
* Fri Dec 14 2018 lbeltrame@kde.org
- Update to 18.12.0
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.0.php
- Changes since 18.11.90:
  * No code changes since 18.11.90
* Mon Dec  3 2018 lbeltrame@kde.org
- Update to 18.11.90
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12-rc.php
- Changes since 18.11.80:
  * No code changes since 18.11.80
* Tue Nov 20 2018 Luca Beltrame <lbeltrame@kde.org>
- Run spec-cleaner
* Tue Nov 20 2018 lbeltrame@kde.org
- Update to 18.11.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12-beta.php
- Changes since 18.08.3:
  * No code changes since 18.08.3
* Thu Nov  8 2018 lbeltrame@kde.org
- Update to 18.08.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08.3.php
- Changes since 18.08.2:
  * No code changes since 18.08.2
* Thu Oct 11 2018 lbeltrame@kde.org
- Update to 18.08.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08.2.php
- Changes since 18.08.1:
  * None
* Thu Sep  6 2018 lbeltrame@kde.org
- Update to 18.08.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08.1.php
- Changes since 18.08.0:
  * None
* Thu Aug 16 2018 christophe@krop.fr
- Update to 18.08.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08.0.php
- Changes since 18.07.80:
  * None
* Thu Jul 26 2018 lbeltrame@kde.org
- Update to 18.07.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08-beta.php
- Changes since 18.04.3:
  * None
* Fri Jul 13 2018 lbeltrame@kde.org
- Update to 18.04.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04.3.php
- Changes since 18.04.2:
  * None
* Fri Jun  8 2018 lbeltrame@kde.org
- Update to 18.04.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04.2.php
- Changes since 18.04.1:
  * None
* Fri May 11 2018 lbeltrame@kde.org
- Update to 18.04.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04.1.php
- Changes since 18.04.0:
  * None
* Wed Apr 18 2018 lbeltrame@kde.org
- Update to 18.04.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04.0.php
- Changes since 18.03.90:
  * None
* Fri Apr  6 2018 lbeltrame@kde.org
- Update to 18.03.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04-rc.php
- Changes since 17.12.3:
  * Fix X-KDE-Library metadata value with kded_ prefix to match binary name
  * Use explicit
  * Use nullptr
  * Use override
  * Use non-deprecated KDEInstallDirs variables
  * Bump min Qt to 5.9 & min KF5 to 5.37
  * include KDEFrameworkCompilerSettings with NO_POLICY_SCOPE
  * Bump min cmake version to 3.0
* Thu Mar  8 2018 lbeltrame@kde.org
- Update to 17.12.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12.3.php
- Changes since 17.12.2:
  * None
* Wed Feb  7 2018 lbeltrame@kde.org
- Update to 17.12.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12.2.php
- Changes since 17.12.1:
  * None
* Thu Jan 11 2018 lbeltrame@kde.org
- Update to 17.12.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12.1.php
- Changes since 17.12.0:
  * None
* Sat Dec  9 2017 lbeltrame@kde.org
- Update to 17.12.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12.0.php
- Changes since 17.11.90:
  * None
* Sat Dec  2 2017 lbeltrame@kde.org
- Update to 17.11.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12-rc.php
- Changes since 17.11.80:
  * Add missing REQUIRED keyword
* Mon Nov 20 2017 lbeltrame@kde.org
- Update to 17.11.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12-beta.php
- Changes since 17.08.3:
  * Normalize the KIO name and use the json file
  * Properly set the translation domain and rename it
  * Fix error msg: reference the specific library, not KDE
  * Add #include to fix the build
  * Build with framework compiler settings
  * Port to KDE Frameworks 5
* Thu Nov  9 2017 lbeltrame@kde.org
- Update to 17.08.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.08.3.php
- Changes since 17.08.2:
  * None
* Mon Oct 16 2017 lbeltrame@kde.org
- Update to 17.08.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.08.2.php
- Changes since 17.08.1:
  * None
* Thu Sep  7 2017 lbeltrame@kde.org
- Update to 17.08.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.08.1.php
- Changes since 17.08.0:
  * None
* Fri Aug 11 2017 christophe@krop.fr
- Update to KDE Applications 17.08.0
  * New feature release
  * https://www.kde.org/announcements/announce-applications-17.08.0.php
- Changes since 17.04.3 :
  * None
* Sat Aug  5 2017 christophe@krop.fr
- Update to KDE Applications 17.07.90
  * KDE Applications 17.07.90
  * https://www.kde.org/announcements/announce-applications-17.08-rc.php
* Sat Jul 15 2017 lbeltrame@kde.org
- Update to 17.04.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04.3.php
- Changes since 17.04.2:
  * None
* Wed Jun  7 2017 lbeltrame@kde.org
- Update to 17.04.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04.2.php
- Changes since 17.04.1:
  * None
* Wed May 17 2017 lbeltrame@kde.org
- Update to 17.04.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04.1.php
- Changes since 17.04.0:
  * None
* Sun Apr 16 2017 lbeltrame@kde.org
- Update to 17.04.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04.0.php
- Changes since 17.03.90:
  * None
* Wed Apr 12 2017 lbeltrame@kde.org
- Update to 17.03.90
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04-rc.php
- Changes since 17.03.80:
  * None
* Sat Mar 25 2017 lbeltrame@kde.org
- Update to 17.03.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04-beta.php
- Changes since 16.12.3:
  * None
* Thu Mar  9 2017 lbeltrame@kde.org
- Update to 16.12.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-16.12.3.php
- Changes since 16.12.2:
  * None
* Thu Feb  9 2017 lbeltrame@kde.org
- Update to KDE Applications 16.12.2
  * KDE Applications 16.12.2
  * https://www.kde.org/announcements/announce-applications-16.12.2.php
* Sat Jan 14 2017 lbeltrame@kde.org
- - Update to KDE Applications 16.12.1
  * KDE Applications 16.12.1
  * https://www.kde.org/announcements/announce-applications-16.12.1.php
* Tue Dec 13 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.12.0
  * KDE Applications 16.12.0
  * https://www.kde.org/announcements/announce-applications-16.12.0.php
* Sat Dec  3 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.11.90
  * KDE Applications 16.12.0 RC
  * https://www.kde.org/announcements/announce-applications-16.12-rc.php
* Tue Nov 29 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.11.80
  * KDE Applications 16.12.0 Beta
  * https://www.kde.org/announcements/announce-applications-16.12-beta.php
* Wed Nov  9 2016 lbeltrame@kde.org
- Update to KDE Applications 16.08.3
  * KDE Applications 16.08.3
  * https://www.kde.org/announcements/announce-applications-16.08.3.php
* Tue Oct 11 2016 lbeltrame@kde.org
- KDE Applications 16.08.2
  https://www.kde.org/announcements/announce-applications-16.08.2.php
* Fri Sep  9 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.08.1
  * KDE Applications 16.08.1
  * https://www.kde.org/announcements/announce-applications-16.08.1.php
* Fri Aug 12 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.08.0
  * KDE Applications 16.08.0
  * https://www.kde.org/announcements/announce-applications-16.08.0.php
* Mon Aug  8 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.07.90
  * KDE Applications 16.07.90 (16.08-RC)
  * https://www.kde.org/announcements/announce-applications-16.08-rc.php
* Thu Jul  7 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.04.3
  * KDE Applications 16.04.3
  * https://www.kde.org/announcements/announce-applications-16.04.3.php
* Fri Jun 10 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.04.2
  * KDE Applications 16.04.2
  * https://www.kde.org/announcements/announce-applications-16.04.2.php
* Sat May  7 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.04.1
  * KDE Applications 16.04.1
  * https://www.kde.org/announcements/announce-applications-16.04.1.php
* Sun Apr 17 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.04.0
  * KDE Applications 16.04.0
  * https://www.kde.org/announcements/announce-applications-16.04.0.php
* Mon Apr 11 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.03.90
  * KDE Applications 16.04.0 RC
  * https://www.kde.org/announcements/announce-applications-16.04-rc.php
* Sun Mar 13 2016 tittiatcoke@gmail.com
- Update to KDE Applications 15.12.3
  * KDE Applications 15.12.3
  * https://www.kde.org/announcements/announce-applications-15.12.3.php
  * boo#970855
* Sat Feb 13 2016 tittiatcoke@gmail.com
- Update to KDE Applications 15.12.2
  * KDE Applications 15.12.2
  * https://www.kde.org/announcements/announce-applications-15.12.2.php
  * boo#966605
* Sat Jan  9 2016 tittiatcoke@gmail.com
- Update to KDE Applications 15.12.1
  * KDE Applications 15.12.1
  * https://www.kde.org/announcements/announce-applications-15.12.1.php
  * boo#961265
* Sun Dec 13 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.12.0
  * KDE Applications 15.12.0
  * https://www.kde.org/announcements/announce-applications-15.12.0.php
  * boo#958887
* Tue Nov 10 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.08.3
  * KDE Applications 15.08.3
  * https://www.kde.org/announcements/announce-applications-15.08.3.php
  * boo#954531
* Sun Oct 11 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.08.2
  * KDE Applications 15.08.2
  * https://www.kde.org/announcements/announce-applications-15.08.2.php
* Sun Sep 13 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.08.1
  * KDE Applications 15.08.1
  * https://www.kde.org/announcements/announce-applications-15.08.1.php
* Wed Aug 19 2015 cgiboudeaux@gmx.com
- Update to KDE Applications 15.08.0
  * KDE Applications 15.08.0
  * https://www.kde.org/announcements/announce-applications-15.08.0.php
* Fri Aug  7 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.07.90
  * KDE Applications 15.08.0 RC1
  * https://www.kde.org/announcements/announce-applications-15.08-rc.php
* Mon Jul  6 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.04.3
  * KDE Applications 15.04.3
  * https://www.kde.org/announcements/announce-applications-15.04.3.php
* Sat May 30 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.04.2
  * KDE Applications 15.04.2
  * https://www.kde.org/announcements/announce-applications-15.04.2.php
* Mon May 11 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.04.1
  * KDE Applications 15.04.1
  * https://www.kde.org/announcements/announce-applications-15.04.1.php
* Sat Apr 11 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.04.0
  * KDE Applications 15.04.0
  * https://www.kde.org/announcements/announce-applications-15.04.0.php
* Sat Mar 21 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.03.95
  * KDE Applications 15.04 RC
* Sun Mar  8 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.03.80
  * KDE Applications 15.04 Beta
* Tue Mar  3 2015 tittiatcoke@gmail.com
- Update to KDE Applications 14.12.3
  * KDE Applications 14.12.3
  * See https://www.kde.org/announcements/announce-applications-14.12.3.php
* Sun Feb  1 2015 tittiatcoke@gmail.com
- Update to KDE Applications 14.12.2
  * KDE Applications 14.12.2
  * See https://www.kde.org/announcements/announce-applications-14.12.2.php
* Mon Jan 12 2015 tittiatcoke@gmail.com
- Update to KDE Applications 14.12.1
  * KDE Applications 14.12.1
  * See https://www.kde.org/announcements/announce-applications-14.12.1.php
* Wed Dec 17 2014 tittiatcoke@gmail.com
- Update to KDE Applications 14.12.0
  * KDE Applications 14.12.0
  * See https://www.kde.org/announcements/announce-applications-14.12.0.php
* Sun Nov  9 2014 tittiatcoke@gmail.com
- Update to 4.14.3
  * KDE 4.14.3 SC Bugfix Release
  * See http://www.kde.org/announcements/announce-4.14.3.php
* Sun Oct 12 2014 tittiatcoke@gmail.com
- Update to 4.14.2
  * KDE 4.14.2 SC Bugfix Release
  * See http://www.kde.org/announcements/announce-4.14.2.php
* Sat Sep 13 2014 tittiatcoke@gmail.com
- Update to 4.14.1
  * KDE 4.14.1 SC Bugfix Release
  * See http://www.kde.org/announcements/announce-4.14.1.php
* Fri Aug 15 2014 tittiatcoke@gmail.com
- Update to 4.14.0
  * KDE 4.14.0 SC Final Release
  * See http://www.kde.org/announcements/4.14/
* Thu Jul 17 2014 cgiboudeaux@gmx.com
- Update to 4.13.90
  * KDE 4.14 Beta 2 release
  * See http://www.kde.org/announcements/announce-4.14-beta2.php
* Thu Jul 10 2014 cgiboudeaux@gmx.com
- Update to 4.13.80
  * KDE 4.14 Beta 1 release
  * See http://www.kde.org/announcements/announce-4.14-beta1.php
* Sun Jun  8 2014 tittiatcoke@gmail.com
- Update to 4.13.2
  * KDE 4.13  release
  * See http://www.kde.org/announcements/announce-4.13.2.php
* Fri May  9 2014 tittiatcoke@gmail.com
- Update to 4.13.1
  * KDE 4.13.1  bug fix release
  * See http://www.kde.org/announcements/announce-4.13.1.php
* Fri Apr 11 2014 tittiatcoke@gmail.com
- Update to 4.13.0
  * KDE 4.13  release
  * See http://www.kde.org/announcements/4.13/
* Thu Mar 27 2014 tittiatcoke@gmail.com
- Update to 4.12.97
  * KDE 4.13 RC  release
  * See http://www.kde.org/announcements/announce-4.13-rc.php
* Thu Mar 20 2014 tittiatcoke@gmail.com
- Update to 4.12.95
  * KDE 4.13 Beta 3  release
  * See http://www.kde.org/announcements/announce-4.13-beta3.php
- Repository was renamed upstream to zeroconf-ioslave.
* Thu Mar 13 2014 tittiatcoke@gmail.com
- Update to 4.12.90
  * KDE 4.13 Beta 2  release
  * See http://www.kde.org/announcements/announce-4.13-beta2.php
* Fri Mar  7 2014 tittiatcoke@gmail.com
- Update to 4.12.80
  * KDE 4.13 Beta 1  release
  * See http://www.kde.org/announcements/announce-4.13-beta1.php
* Sat Feb  1 2014 tittiatcoke@gmail.com
- Update to 4.12.2
  * KDE 4.12.2  release
  * See http://www.kde.org/announcements/announce-4.12.2.php
* Sat Jan 11 2014 tittiatcoke@gmail.com
- Update to 4.12.1
  * KDE 4.12.1  release
  * See http://www.kde.org/announcements/announce-4.12.1.php
* Sat Dec 14 2013 tittiatcoke@gmail.com
- Update to 4.12.0
  * KDE 4.12.0  release
  * See http://www.kde.org/announcements/4.12.php
* Fri Nov 29 2013 tittiatcoke@gmail.com
- Update to 4.11.97
  * KDE 4.12 RC 1 release
  * See http://www.kde.org/announcements/announce-4.12-rc.php
* Sat Nov 23 2013 tittiatcoke@gmail.com
- Update to 4.11.95
  * KDE 4.12 Beta 3 release
  * See http://www.kde.org/announcements/announce-4.12-beta3.php
* Sat Nov 16 2013 tittiatcoke@gmail.com
- Update to 4.11.90
  * KDE 4.12 Beta 2 release
  * See http://www.kde.org/announcements/announce-4.12-beta2.php
* Sun Nov 10 2013 tittiatcoke@gmail.com
- Update to 4.11.80
  * KDE 4.12 Beta 1 release
  * See http://www.kde.org/announcements/announce-4.12-beta1.php
* Sat Nov  2 2013 tittiatcoke@gmail.com
- Update to 4.11.3
  * KDE 4.11.3 bugfix release
  * See http://www.kde.org/announcements/announce-4.11.3.php
* Sat Sep 28 2013 tittiatcoke@gmail.com
- Update to 4.11.2
  * KDE 4.11.2 bugfix release
  * See http://www.kde.org/announcements/announce-4.11.2.php
* Sun Sep  1 2013 tittiatcoke@gmail.com
- Update to 4.11.1
  * KDE 4.11.1 bugfix release
  * See http://www.kde.org/announcements/announce-4.11.1.php
* Thu Aug  8 2013 tittiatcoke@gmail.com
- Update to 4.11.0
  * KDE 4.11 Final release
  * See http://www.kde.org/announcements/4.11/
* Thu Jul 25 2013 hrvoje.senjan@gmail.com
- Update to 4.10.97
  * KDE 4.11 RC 2 release
  * See http://www.kde.org/announcements/announce-4.11-rc2.php
* Mon Jul 15 2013 cgiboudeaux@gmx.com
- Update to 4.10.95
  * KDE 4.11 RC 1 release
  * See http://www.kde.org/announcements/announce-4.11-rc1.php
* Wed Jul  3 2013 tittiatcoke@gmail.com
- Update to 4.10.90
  * KDE 4.11 Beta 2 release
  * See http://www.kde.org/announcements/announce-4.11-beta2.php
* Thu Jun 13 2013 tittiatcoke@gmail.com
- Update to 4.10.80
  * KDE 4.11 Beta 1 release
  * See http://www.kde.org/announcements/announce-4.11-beta1.php
  * Split off from kdenetwork4
* Sat Jun  1 2013 tittiatcoke@gmail.com
- Update to 4.10.4
  * Bugfix release
  * See http://www.kde.org/announcements/announce-4.10.4.php
  * resolves bnc#8122760
- Dropped fix_v4l_deprecations.patch, it's included in this release
* Wed May  8 2013 nico.kruber@gmail.com
- re-enable OTR plugin for openSUSE 12.3 and Factory
  (using with libotr2 which provides version 3.2.*)
- re-enable libktorrent support
* Sat May  4 2013 tittiatcoke@gmail.com
- Update to 4.10.3
  * Bugfix release
  * See http://www.kde.org/announcements/announce-4.10.3.php
  * resolves bnc#818500
- Added fix_v4l_deprecations.patch, fixes usage of interfaces deprecated
  with 3.9 kernel
* Mon Apr  1 2013 tittiatcoke@gmail.com
- Update to 4.10.2 \n  * Bugfixes
* Tue Mar 12 2013 seife+obs@b1-systems.com
- fix build with giflib-5 (kdenetwork-4.10.0-giflib5.patch)
* Sat Mar  2 2013 tittiatcoke@gmail.com
- Update to 4.10.1
  * Contains bug fixes. See http://www.kde.org/announcements/
  for more information
* Thu Jan 31 2013 tittiatcoke@gmail.com
- Update to 4.10.0
  * This is the final release for 4.10. Contains bugfixes
* Thu Jan 17 2013 tittiatcoke@gmail.com
- Update to 4.9.98
  * This is the third RC release for 4.10. Contains bugfixes
* Thu Jan  3 2013 tittiatcoke@gmail.com
- Update to 4.9.97
  * This is the second RC release for 4.10. Contains bugfixes
* Wed Dec 19 2012 tittiatcoke@gmail.com
- Update to 4.9.95
  * This is the first RC release for 4.10. Contains bugfixes
* Sat Dec  1 2012 tittiatcoke@gmail.com
- Update to 4.9.90
  * This is the second Beta release for 4.10. Contains bugfixes
* Sat Nov 24 2012 tittiatcoke@gmail.com
- Update to 4.9.80
  * See http://www.kde.org/announcements/announce-4.10-beta1.php
* Wed Nov  7 2012 tittiatcoke@gmail.com
- Add explicit buildrequire for libmediastreamer1 for kopete to
  avoid "Have Choice for" for packages depending on Kopete and to
  prevent that the user has to make a choice what to install
* Fri Nov  2 2012 tittiatcoke@gmail.com
- Update to 4.9.3
  * see http://kde.org/announcements/announce-4.9.3.php for details
* Wed Oct 10 2012 mailaender@opensuse.org
- replace dependency on linphone GUI with pure mediastreamer/ortp
* Sat Oct  6 2012 tittiatcoke@gmail.com
- Disable the OTR plugin for openSUSE Factory atm due to
  incompatibility with the newer libotr version
* Sat Sep 29 2012 tittiatcoke@gmail.com
- Update to 4.9.2
  * see http://kde.org/announcements/announce-4.9.2.php for details
* Wed Sep  5 2012 dmueller@suse.com
- update to 4.9.1
  * see http://kde.org/announcements/4.9.1/ for details
* Mon Jul 30 2012 dmueller@suse.com
- update to 4.8.5
  * see http://kde.org/announcements/changelogs/changelog4_8_4to4_8_5.php for details
* Mon Jun  4 2012 idonmez@suse.com
- Fix build with new glibc
* Fri Jun  1 2012 dmueller@suse.com
- update to 4.8.4
  * see http://kde.org/announcements/changelogs/changelog4_8_3to4_8_4.php for details
* Sun Apr 29 2012 dmueller@suse.com
- update to 4.8.3
  * see http://kde.org/announcements/changelogs/changelog4_8_2to4_8_3.php for details
* Sun Apr  1 2012 dimstar@opensuse.org
- Add kdenetwork4-gcc47.patch: Fix build with gcc 4.7.
* Sat Mar 31 2012 wstephenson@suse.com
- Add xz to BuildRequires
* Thu Mar 29 2012 dmueller@suse.de
- update to 4.8.2
  * see http://kde.org/announcements/changelogs/changelog4_8_1to4_8_2.php for details
* Fri Mar  2 2012 dmueller@suse.de
- update to 4.8.1
  * see http://kde.org/announcements/changelogs/changelog4_8_0to4_8_1.php for details
* Wed Jan 18 2012 dmueller@suse.de
- update to 4.8.0
  * first stable release of KDE 4.8 (only critical fixes over 4.7.98)
  * see http://kde.org/announcements/4.8/ for details
* Tue Jan 10 2012 dmueller@suse.de
- update to 4.7.98
  * RC2+ milestone release of KDE 4.8
  * see http://kde.org/announcements/4.8/ for details
* Wed Dec  7 2011 coolo@suse.com
- fix license to be in spdx.org format
* Fri Dec  2 2011 dmueller@suse.de
- update to 4.7.4
  * see http://kde.org/announcements/changelogs/changelog4_7_3to4_7_4.php for details
* Fri Nov 11 2011 idonmez@suse.com
- Depend on kwebkitpart instead of kwebkitpart-devel
* Wed Nov  2 2011 dmueller@suse.de
- update to 4.7.3
  * see http://kde.org/announcements/changelogs/changelog4_7_2to4_7_3.php for details
* Sun Oct  2 2011 dmueller@suse.de
- update to 4.7.2
  * see http://kde.org/announcements/changelogs/changelog4_7_1to4_7_2.php for details
* Sat Sep 17 2011 toddrme2178@gmail.com
- Removed base package (fix for RPMLINT warning)
- Removed KDE 3 provides and obsoletes (fix for RPMLINT warning)
- Updated groups (fix for RPMLINT warning)
- Split krdc devel package (fix for RPMLINT warning)
- Changed filesharing summary and description to accurately reflect contents
- Cleaned up spec file formatting
* Fri Sep  2 2011 dmueller@suse.de
- update to 4.7.1
  * Bugfixes over KDE 4.7.0
  * see http://kde.org/announcements/changelogs/changelog4_7_0to4_7_1.php for details
* Fri Jul 22 2011 dmueller@suse.de
- update to 4.7.0
  * Small fixes over KDE 4.7 RC2
  * see http://kde.org/announcements/4.7 for details
* Thu Jul 21 2011 idonmez@novell.com
- Update to 4.6.95
* Fri Jul  1 2011 dmueller@suse.de
- update to 4.6.5
  * Bugfixes over KDE 4.6.5
  * see http://kde.org/announcements/changelogs/changelog4_6_4to4_6_5.php for details
* Fri Jun  3 2011 dmueller@suse.de
- update to 4.6.4
  * Bugfixes over KDE 4.6.3
  * see http://kde.org/announcements/changelogs/changelog4_6_3to4_6_4.php for details
* Thu Apr 28 2011 dmueller@suse.de
- update to 4.6.3
  * Bugfixes over KDE 4.6.2
  * see http://kde.org/announcements/changelogs/changelog4_6_2to4_6_3.php for details
* Fri Apr  1 2011 dmueller@suse.de
- update to 4.6.2
  * Bugfixes over KDE 4.6.1
  * see http://kde.org/announcements/changelogs/changelog4_6_1to4_6_2.php for details
* Tue Mar  8 2011 dmueller@suse.de
- update to 4.6.1
  * Bugfixes over KDE 4.6.0
  * see http://kde.org/announcements/changelogs/changelog4_6_0to4_6_1.php for details
* Wed Jan 19 2011 dmueller@suse.de
- update to 4.6.0
  * For highlights, see http://kde.org/announcements/4.6
* Tue Jan  4 2011 dmueller@suse.de
- update to 4.5.95
  * KDE 4.6 RC2
  * no upstream changelog available.
* Wed Dec 22 2010 dmueller@suse.de
- update to 4.5.90
  * KDE 4.6 RC1
  * no upstream changelog available.
* Wed Dec  8 2010 toddrme2178@gmail.com
- Add optional dependencies
  * KDE4Workspace -- Allows 'shutdown after downloads completed' in kget
  * libkonq       -- Needed to build actions and open with options in the context menu of a transfer
  * mediastreamer -- Required to enable voice clips support in WLM plugin and
    needed to build Google Talk libjingle audio call support in Kopete.
  * Expat         -- Needed to build Google Talk libjingle support
- Removed build tests for unsupported openSUSE versions (11.0 and earlier)
* Fri Dec  3 2010 dmueller@suse.de
- update to 4.5.85
  * KDE 4.6 Beta2
  * Final Beta before RC, various fixes from Beta1
  * no upstream changelog available.
* Mon Nov 22 2010 coolo@novell.com
- ran spec-cleaner and disabled libktorrent support for now
  (needs work upstream)
* Mon Nov 22 2010 coolo@novell.com
- remove patch already upstream (kopete icq)
* Fri Nov 19 2010 dmueller@suse.de
- update to 4.5.80
  * KDE 4.6 Beta1
  * no upstream changelog available.
* Thu Oct 28 2010 dmueller@suse.de
- update to 4.5.3
  * see http://kde.org/announcements/changelogs/changelog4_5_2to4_5_3.php for details
* Thu Sep 30 2010 dmueller@suse.de
- update to 4.5.2
  * see http://kde.org/announcements/changelogs/changelog4_5_1to4_5_2.php for details
* Fri Aug 27 2010 dmueller@suse.de
- update to 4.5.1
  * see http://kde.org/announcements/changelogs/changelog4_5_0to4_5_1.php for details
* Thu Jul 29 2010 dmueller@suse.de
- update to 4.5.0
  * KDE 4.5.0 final (version bump over RC3)
* Fri Jul 23 2010 dmueller@suse.de
- update to 4.4.95
  * KDE 4.5 RC3 (not announced)
  * critical fixes for 4.5.0 release
* Wed Jul 21 2010 llunak@novell.com
- build KGet with Torrent support
* Fri Jul 16 2010 dmueller@suse.de
- update to 4.4.93svn1149349
* Wed Jul  7 2010 dmueller@suse.de
- update to 4.4.5
  * bugfixes over 4.4.4
  * see http://kde.org/announcements/changelogs/changelog4_4_4to4_4_5.php for details
* Fri Jun 18 2010 dmueller@suse.de
- update to 4.4.4
  * bugfixes over 4.4.3
  * see http://kde.org/announcements/changelogs/changelog4_4_3to4_4_ 4.php for details
  * for most modules only version number as a change (4_4_BRANCH.diff already contained the diff
* Wed Jun 16 2010 wstephenson@novell.com
- add fix for parsing tags in OTR messages (bko#233330)
* Fri May 28 2010 llunak@novell.com
- disable Samba configuration module, YaST should be used instead
  (bnc#608502)
* Mon May 17 2010 llunak@novell.com
- update 4_4_BRANCH.diff: various fixes, translation updates
* Wed May 12 2010 wstephenson@novell.com
- Fix KGet security issue with specially crafted metalink files.
  (CVE-2010-1000, bnc#604709)
* Thu Apr 29 2010 dmueller@suse.de
- update to 4.4.3
  * bugfixes over 4.4.2
  * see http://kde.org/announcements/changelogs/changelog4_4_2to4_4_3.php for details
* Fri Mar 26 2010 dmueller@suse.de
- update to 4.4.2
  * bugfixes over 4.4.1
  * see http://kde.org/announcements/changelogs/changelog4_4_1to4_4_2.php for details
* Fri Feb 26 2010 dmueller@suse.de
- update to 4.4.1
  * bugfixes over 4.4.0
  * see http://kde.org/announcements/changelogs/changelog4_4_0to4_4_1.php for details
* Wed Feb 10 2010 llunak@novell.com
- add kwebkitpart-devel buildrequires
* Thu Feb  4 2010 dmueller@suse.de
- update to 4.4.0
  * Critical bugfixes only over 4.3.98
  * see http://www.kde.org/announcements/4.4/ for general overview
* Sun Jan 31 2010 dmueller@suse.de
- update to 4.3.98
  * see http://www.kde.org/announcements/announce-4.4-rc3.php for details
* Wed Jan 20 2010 dmueller@suse.de
- update to 4.3.95
  * see http://www.kde.org/announcements/announce-4.4-rc2.php for details
* Wed Jan  6 2010 dmueller@suse.de
- update to 4.3.90
  * see http://www.kde.org/announcements/announce-4.4-rc1.php for details
* Fri Dec 18 2009 dmueller@suse.de
- update to 4.3.85
  * see http://www.kde.org/announcements/announce-4.4-beta2.php for details
* Fri Dec  4 2009 dmueller@suse.de
- update to 4.3.80
  * see http://techbase.kde.org/Schedules/KDE4/4.4_Feature_Plan
* Tue Nov  3 2009 dmueller@suse.de
- tighten the version dep on libmsn as it breaks ABI quite often
* Mon Nov  2 2009 dmueller@suse.de
- update to 4.3.3
  * see http://kde.org/announcements/changelogs/changelog4_3_2to4_3_3.php for details
* Thu Sep 24 2009 beineri@opensuse.org
- update 4_3_BRANCH.diff:
  * fix krfb producing garbled display (kde#162493)
  * fix kget repeating old downloads on startup (kde#170496)
  * several kopete bug fixes
* Wed Sep  9 2009 beineri@opensuse.org
- update 4_3_BRANCH.diff: Kopete winpopup fixes
* Fri Aug 28 2009 dmueller@suse.de
- update to 4.3.1
  * see http://kde.org/announcements/changelogs/changelog4_3_0to4_3_1.php for details
* Thu Aug 20 2009 aj@suse.de
- Use libiw-devel instead of wireless-tools for building.
* Sat Aug 15 2009 beineri@opensuse.org
- branch diff update: krdc, kopete and kget fixes
* Fri Aug  7 2009 beineri@opensuse.org
- add recommendation for kopete-protocol-facebook to kopete package
* Wed Jul 29 2009 dmueller@suse.de
- update to 4.3.0
  * see http://kde.org/announcements/4.3 for details
* Tue Jul 21 2009 dmueller@suse.de
- update to 4.2.98
* Thu Jul  9 2009 dmueller@suse.de
- update to 4.2.96
* Wed Jul  1 2009 beineri@opensuse.org
- update branch diff to fix Kopete Yahoo protocol (bnc#516347)
* Wed Jun 24 2009 dmueller@suse.de
- update to 4.2.95
* Sat Jun 20 2009 beineri@opensuse.org
- drop kde4- package prefixes
* Wed Jun  3 2009 dmueller@suse.de
- update to 4.2.90
* Fri May 29 2009 beineri@opensuse.org
- fix location of brower plugin (bnc#508069)
* Wed May 27 2009 dmueller@suse.de
- update to 4.2.88svn973768
* Thu May 14 2009 dmueller@suse.de
- update to 4.2.85 (KDE 4.3 Beta1)
* Thu Apr 30 2009 dmueller@suse.de
- update to 4.2.3
  * see http://kde.org/announcements/changelogs/changelog4_2_2to4_2_3.php
* Thu Mar 26 2009 dmueller@suse.de
- update to 4.2.2
  * see http://kde.org/announcements/changelogs/changelog4_2_1to4_2_2.php
* Sun Mar 22 2009 beineri@opensuse.org
- fix build against new webkitkde
- update branch diff
* Fri Feb 27 2009 dmueller@suse.de
- update to 4.2.1
  * see http://kde.org/announcements/changelogs/changelog4_2_0to4_2_1.php
* Thu Feb 19 2009 stbinner@suse.de
- update branch diff
* Fri Feb  6 2009 stbinner@suse.de
- branch diff update: Kopete bug fixes
* Thu Jan 22 2009 dmueller@suse.de
- update to 4.2.0
* Tue Jan 13 2009 dmueller@suse.de
- update to 4.1.96
* Sat Jan 10 2009 dmueller@suse.de
- update to KDE 4.1.87 (KDE 4.2 Januar snapshot)
* Tue Dec 16 2008 stbinner@suse.de
- versionized split-provides are not supported
* Fri Dec  5 2008 wstephenson@suse.de
- Fix Kopete mainwindow save/restore (bnc#440801)
* Thu Nov 20 2008 stbinner@suse.de
- add SLE provides/obsoletes
* Tue Nov 18 2008 stbinner@suse.de
- fix krdc cancelling KDE logout (bnc#442767)
- update Kopete logout crash fix (bnc#435155)
* Wed Nov  5 2008 dmueller@suse.de
- use minimal-toc to fix build for ppc(64)
* Fri Oct 31 2008 dmueller@suse.de
- update to 4.1.3
  * see http://kde.org/announcements/changelogs/changelog4_1_2to4_1_3.php
* Tue Oct 21 2008 stbinner@suse.de
- update branch diff:
  * remember custom resolution
  * fix some Kopete login and shutdown crashes
* Sat Sep 27 2008 wstephenson@suse.de
- Update branch diff
  * fix bnc#396381 kopete crashes on adding groupwise contacts
  * fix bnc#336059 kopete crashes in GW::UserDetailsManager
  * fix bnc#403147 kopete shows '0' in place of contact name for
    off-contact-list incoming messages
* Thu Sep 25 2008 dmueller@suse.de
- update to 4.1.2
  * see http://kde.org/announcements/changelogs/changelog4_1_1to4_1_2.php
* Mon Sep  8 2008 stbinner@suse.de
- branch diff update
* Thu Sep  4 2008 wstephenson@suse.de
- Comprehensive lockdown (Kiosk) support for Kopete
* Thu Aug 28 2008 dmueller@suse.de
- update to 4.1.1
  * see http://kde.org/announcements/changelogs/changelog4_1to4_1_1.php
* Sat Aug 16 2008 stbinner@suse.de
- branch diff update
* Thu Jul 31 2008 dmueller@suse.de
- branch diff update
* Wed Jul 23 2008 dmueller@suse.de
- update to 4.1.0
* Thu Jul 17 2008 dmueller@suse.de
- update to 4.0.99
* Fri Jul 11 2008 dmueller@suse.de
- update to 4.0.98
* Mon Jul  7 2008 dmueller@suse.de
- update to 4.0.85
* Mon Jun 30 2008 dmueller@suse.de
- update filelist
* Thu Jun 26 2008 dmueller@suse.de
- update to 4.0.84
* Wed Jun 18 2008 dmueller@suse.de
- update to 4.0.83
* Tue Jun 10 2008 dmueller@suse.de
- update to 4.0.82
* Mon Jun  9 2008 dmueller@suse.de
- update to 4.0.81
* Thu Jun  5 2008 wstephenson@suse.de
- Hint that kdenetwork4-filesharing should be installed to support
  Dolphin's filesharing function. (bnc#396242)
- Fix crash on incoming offline message (bnc#389408)
* Wed Jun  4 2008 dmueller@suse.de
- fix krdc crash on connect (bnc#396760)
* Tue May 27 2008 stbinner@suse.de
- don't crash when right-clicking the newsticker (bnc#386611)
* Tue May 27 2008 dmueller@suse.de
- fix kdepimlibs requires
* Sun May 11 2008 wstephenson@suse.de
- 4_0_BRANCH.diff update:
  * Fix #335679 - unable to add groupwise contact correctly
  * Fix #383679 - crashes on adding contacts to existing groups
  * Fix #378646 - groupwise contacts not shown in contact list
* Fri May  9 2008 dmueller@suse.de
- 4_0_BRANCH.diff update:
  * new translations, various groupwise fixes
* Fri May  9 2008 wstephenson@suse.de
- Fix GroupWise contacts not appearing on connect (#378646)
* Thu May  1 2008 dmueller@suse.de
- update to 4.0.4
  * http://www.kde.org/announcements/changelogs/changelog4_0_3to4_0_4.php
* Mon Apr 14 2008 dmueller@suse.de
- update 4_0_BRANCH.diff
* Thu Mar 27 2008 dmueller@suse.de
- update to 4.0.3
* Thu Mar  6 2008 stbinner@suse.de
- default knewsticker plasmoid to paging style - uses much less cpu
* Tue Mar  4 2008 stbinner@suse.de
- update to 4.0.2
* Mon Feb 18 2008 stbinner@suse.de
- update branch diff after Plasma backport week-end
* Sat Feb 16 2008 dmueller@suse.de
- move kget icon to hicolor
* Fri Feb 15 2008 dmueller@suse.de
- update 4_0_BRANCH.diff
* Thu Jan 31 2008 dmueller@suse.de
- update to 4.0.1
* Sun Jan 20 2008 stbinner@suse.de
- update KDE_4_0_BRANCH.diff
* Sat Jan  5 2008 stbinner@suse.de
- update to 4.0 release
* Wed Jan  2 2008 stbinner@suse.de
- update to 3.97.2
* Sun Dec 16 2007 dmueller@suse.de
- update to 3.97.1
* Wed Dec  5 2007 dmueller@suse.de
- update to 3.97.0
* Tue Dec  4 2007 dmueller@suse.de
- update to 3.96.3
* Wed Nov 28 2007 dmueller@suse.de
- update to 3.96.2
* Wed Nov 21 2007 dmueller@suse.de
- update to 3.96.1
* Wed Nov 14 2007 dmueller@suse.de
- update to 3.96.0
* Wed Nov  7 2007 dmueller@suse.de
- update to 3.95.2
* Mon Nov  5 2007 dmueller@suse.de
- fix directory ownership
* Mon Nov  5 2007 dmueller@suse.de
- suppress desktop icon errors for now
* Thu Nov  1 2007 dmueller@suse.de
- update to 3.95.1
* Fri Oct 26 2007 dmueller@suse.de
- update to KDE 4.0 beta4
* Tue Oct 23 2007 dmueller@suse.de
- remove reference to uninstalled icon file
* Thu Oct 18 2007 dmueller@suse.de
- udpate to 3.94.1
* Tue Oct  9 2007 dmueller@suse.de
- update to KDE 4.0 beta3
* Tue Oct  2 2007 stbinner@suse.de
- update to 3.93.0.svn720135
* Wed Sep 26 2007 stbinner@suse.de
- update to 3.93.0.svn717255
* Mon Sep 24 2007 stbinner@suse.de
- two krfb fixes from upstream (#325543):
  * don't crash after deleting the first invitation in the list
    if there are more than one
  * be able to connect to the VNC server right after the invitation
    has been created; don't wait until the dialog has been closed
* Mon Sep 17 2007 dmueller@suse.de
- fix threading issues in krdc (#310766)
* Fri Sep 14 2007 stbinner@suse.de
- link krfb and krdc icons so that all 10.3 default apps have icons
* Thu Sep 13 2007 stbinner@suse.de
- update to 3.93.0.svn712057
* Tue Sep  4 2007 stbinner@suse.de
- fix dependencies of kdenetwork4-devel if built without Kopete
* Thu Aug 30 2007 dmueller@suse.de
- update to KDE 4.0 Beta 2
* Thu Aug 23 2007 stbinner@suse.de
- update to 3.92.0.svn705096
* Thu Aug 16 2007 stbinner@suse.de
- update to 3.92.0.svn700763
* Thu Aug  9 2007 stbinner@suse.de
- update to 3.92.0.svn697375
* Mon Aug  6 2007 dmueller@suse.de
- fix build
* Sun Jul 29 2007 stbinner@suse.de
- update to KDE 4.0 Beta 1
* Thu Jul 19 2007 stbinner@suse.de
- fix suse_update_desktop_file call
- fix build after LibVNCServer split
* Thu Jul 12 2007 stbinner@suse.de
- update to 3.91.0.svn686458
* Wed Jun 27 2007 stbinner@suse.de
- update to 3.90.1.svn672301
* Mon Jun 25 2007 stbinner@suse.de
- update to 3.90.1.svn679956
* Fri Jun  8 2007 stbinner@suse.de
- update to 3.90.1.svn670093
* Mon Jun  4 2007 stbinner@suse.de
- fix build
* Fri Jun  1 2007 coolo@suse.de
- simplify spec file by using macros from kde4-filesystem
* Mon May 28 2007 dmueller@suse.de
- update to 3.90.1.svn668119
* Wed May 23 2007 dmueller@suse.de
- add kdenetwork4-devel subpackage
* Fri May 18 2007 stbinner@suse.de
- initial package in abuild
